@@ -24,7 +24,7 @@ from pathlib import Path
 from subprocess import PIPE, Popen
 from typing import Set, Tuple, Union
 
-from darker.git import EditedLinenumsDiffer
+from darker.git import WORKTREE, EditedLinenumsDiffer, RevisionRange
 
 logger = logging.getLogger(__name__)
 
@@ -58,17 +58,24 @@ def _parse_linter_line(
     return path_in_repo, linenum
 
 
-def run_linter(cmdline: str, git_root: Path, paths: Set[Path], revision: str) -> None:
+def run_linter(
+    cmdline: str, git_root: Path, paths: Set[Path], revrange: RevisionRange
+) -> None:
     """Run the given linter and print linting errors falling on changed lines
 
     :param cmdline: The command line for running the linter
     :param git_root: The repository root for the changed files
     :param paths: Paths of files to check, relative to ``git_root``
-    :param revision: The Git revision against which to compare the working tree
+    :param revrange: The Git revision rango to compare
 
     """
     if not paths:
         return
+    if revrange.rev2 is not WORKTREE:
+        raise NotImplementedError(
+            "Linting arbitrary commits is not supported. "
+            "Please use -r {<rev>|<rev>..|<rev>...} instead."
+        )
     linter_process = Popen(
         cmdline.split() + [str(git_root / path) for path in sorted(paths)],
         stdout=PIPE,
@@ -76,12 +83,12 @@ def run_linter(cmdline: str, git_root: Path, paths: Set[Path], revision: str) ->
     )
     # assert needed for MyPy (see https://stackoverflow.com/q/57350490/15770)
     assert linter_process.stdout is not None
-    edited_linenums_differ = EditedLinenumsDiffer(git_root, revision)
+    edited_linenums_differ = EditedLinenumsDiffer(git_root, revrange)
     for line in linter_process.stdout:
         path_in_repo, linter_error_linenum = _parse_linter_line(line, git_root)
         if path_in_repo is None:
             continue
-        edited_linenums = edited_linenums_differ.revision_vs_worktree(
+        edited_linenums = edited_linenums_differ.compare_revisions(
             path_in_repo, context_lines=0
         )
         if linter_error_linenum in edited_linenums:
